function [V, D] = miobiEigen(V0, D0, Ad, t)
%{
 Goal : Update eigen decomposition

 Input:
   V0: eigen vectors of A (old matrix)
   D0: eigen values of A
   Ad: perturbation (low rank)
   t: top t eigen decomposition of Ad

 Output:
   V: eigen vectors of new A
   D: eigen values of new A

 Reference: 
   Chan, Hau, Leman Akoglu, and Hanghang Tong. 
   "Make It or Break It: Manipulating Robustness 
   in Large Networks." SDM. 2014.
%}

 for tt=1:t
  Dd0(tt,tt)=(V0(:,tt)')*Ad*V0(:,tt);
  Dd0(tt,tt)=(Dd0(tt,tt)+Dd0(tt,tt)')/2;
 end
  D=D0+Dd0;


Vd0=zeros(size(V0,1),t);
for j=1:t
    for i=1:t
        if (i~=j)
            Vd0(:,j)=Vd0(:,j)+((V0(:,i)')*Ad*V0(:,j))*V0(:,i)/(D0(j,j)-D0(i,i));
        end
    end
end
 V=V0+Vd0;

end