function [V, D] = udEigen(V0, D0, i, j,n, t)
%{
 Goal : Update eigen decomposition
 Author: Ruiyue Peng (rpeng8@asu.edu)

 Input:
   V0: eigen vectors of A (old matrix)
   D0: eigen values of A
   Ad: perturbation (low rank)
   t: top t eigen decomposition of Ad

 Output:
   V: eigen vectors of new A
   D: eigen values of new A
%}
    
          Y=[1 0; 0 -1];
          X=zeros(n,2);
          X(i,1)=1/sqrt(2);
          X(j,1)=-1/sqrt(2);
          X(i,2)=-1/sqrt(2);
          X(j,2)=-1/sqrt(2);

     [Q, R] = myQR(V0, X,i,j);
    
    M = diag([diag(D0);diag(Y)]);
    Z = R*M*R';
    Z = (Z+Z')/2;
    
    rk = rank(Z);
    if rk < size(Z, 1)
        [V, D] = eigs(Z, rk);
    else
        [V, D] = eig(Z);
    end
    
    V = Q*V;
    [~,ind] = sort(abs(diag(D)),'descend');
    top_r = min(size(V0,2),length(ind));
    ind = ind(1:top_r);
    D = D(ind,ind);
    V = V(:,ind);
end